==> eslint-plugin-woke-0.1.0.tgz: package/lib/categories/LGBTQ.js <==
module.exports = [
  {
    description: '"{word}" is a slur against LGBTQ people',
    words: ['bender', 'deviant']
  }, {
    description: '"{word}" is a slur against men',
    words: [
      "sissy', 'girlieman', 'pansy', 'janus', 'sodomite', 'nancy', 'poof', 'poofter",
      "fairy', 'brownie', 'pillowbiter', 'bugger', 'cola', 'fudgepacker', 'nelly"
    ]
  }, {
    description: '"{word}" is a slur against women',
    words: ['faghag', 'fish', 'rugmuncher', 'marimacho', 'bitch']
  }, {
    description: '"{word}" is a slur against homosexuals',
    words: ['homo', 'homintern', 'invert', 'bent']
  }, {
    description: '"{word}" is a slur against gay men',
    words: [
      "faggot', 'fag', 'fjolla', 'machobög', 'viado', 'shirtlifter', 'bardash', 'bakla",
      "batiman","flamer","flaming","fruit","moffie","ponce","tapette","steamer",
      "nola', 'flit', 'daffodil', 'jocker', 'quean', 'greek', 'tonk', 'lizzie",
      "wonk', 'dorian', 'poove', 'sod', 'fairy', 'ogay', 'battyboy', 'battyman",
      "nancy', 'nancyboy', 'woofter', 'twinkie', 'twink', 'swish', 'nelly', 'nellie"
    ]
  }, {
    description: '"{word}" is a slur against lesbians',
    words: ['dyke', 'bollera', 'lesbo', 'flata', 'bofe', 'caminhoneira', 'gouine', 'goudou']
  }, {
    description: '"{word}" is a slur against bisexual people',
    words: ['acdc', 'switchhitter']
  }, {
    description: '"{word}" is a slur against bisexual women',
    words: ['lug', 'fauxbians']
  }, {
    description: '"{word}" is a slur against transgender people',
    words: ['tranny', 'trannie', 'shim', 'heshe', 'transtrender', 'troon', 'it']
  }, {
    description: '"{word}" is a slur against trans men',
    words: ['cuntboy', 'hefemale']
  }, {
    description: '"{word}" is a slur against trans women',
    words: ['shemale', 'dickgirl', 'ladyboy', 'mahu', 'shim', 'trap', 'tim']
  }, {
    description: '"{word}" is a slur against LGBTQ intersex people',
    words: ['hermie', 'hybrid']
  }, {
    description: '"{word}" is a slur against intersex men',
    words: ['napumsaka']
  }, {
    description: '"{word}" is a slur against cross-dressers',
    words: ['transa', 'transvestite', 'quean']
  }, {
    description: '"{word}" is a slur against cross-dressing men',
    words: ['pondan', 'tranny', 'sheman', 'okama', 'banci', 'bencong']
  }, {
    description: '"{word}" is a slur against cross-dressing women',
    words: ['hommasse', 'hermaphroditi']
  }, {
    description: '"{word}" is a slur against androgynous people',
    words: ['berdache']
  }, {
    description: '"{word}" is a slur against androgynous men',
    words: ['breckgirl']
  }
];

==> eslint-plugin-woke-1.0.1.tgz: package/lib/categories/LGBTQ.js <==
module.exports = [
  {
    description: '"{word}" is a slur against LGBTQ people',
    words: ['bender', 'deviant']
  }, {
    description: '"{word}" is a slur against men',
    words: [
      'sissy', 'girlieman', 'pansy', 'janus', 'sodomite', 'nancy', 'poof', 'poofter',
      'fairy', 'brownie', ['pillow','biter'], 'bugger', 'cola', ['fudge','packer'], 'nelly'
    ]
  }, {
    description: '"{word}" is a slur against women',
    words: [['fag','hag'], 'fish', ['rug','muncher'], 'marimacho', 'bitch']
  }, {
    description: '"{word}" is a slur against homosexuals',
    words: ['homo', 'homintern', 'invert', 'bent']
  }, {
    description: '"{word}" is a slur against gay men',
    words: [
      'faggot', 'fag', 'fjolla', 'machobög', 'viado', ['shirt','lifter'], 'bardash', 'bakla',
      'batiman','flamer','flaming','fruit','moffie','ponce','tapette','steamer',
      'nola', 'flit', 'daffodil', 'jocker', 'quean', 'greek', 'tonk', 'lizzie',
      'wonk', 'dorian', 'poove', 'sod', 'fairy', 'ogay', ['batty','boy'], ['batty','man'],
      'nancy', ['nancy','boy'], 'woofter', 'twinkie', 'twink', 'swish', 'nelly', 'nellie'
    ]
  }, {
    description: '"{word}" is a slur against lesbians',
    words: ['dyke', 'bollera', 'lesbo', 'flata', 'bofe', 'caminhoneira', 'gouine', 'goudou']
  }, {
    description: '"{word}" is a slur against bisexual people',
    words: ['acdc', ['switch','hitter']]
  }, {
    description: '"{word}" is a slur against bisexual women',
    words: ['lug', 'fauxbians']
  }, {
    description: '"{word}" is a slur against transgender people',
    words: ['tranny', 'trannie', 'shim', 'heshe', 'transtrender', 'troon']
  }, {
    description: '"{word}" is a slur against trans men',
    words: [['cunt','boy'], 'hefemale']
  }, {
    description: '"{word}" is a slur against trans women',
    words: [['she','male'], ['dick','girl'], ['lady','boy'], 'mahu', 'shim', 'trap', 'tim']
  }, {
    description: '"{word}" is a slur against LGBTQ intersex people',
    words: ['hermie', 'hybrid']
  }, {
    description: '"{word}" is a slur against intersex men',
    words: ['napumsaka']
  }, {
    description: '"{word}" is a slur against cross-dressers',
    words: ['transa', 'transvestite', 'quean']
  }, {
    description: '"{word}" is a slur against cross-dressing men',
    words: ['pondan', 'tranny', 'sheman', 'okama', 'banci', 'bencong']
  }, {
    description: '"{word}" is a slur against cross-dressing women',
    words: ['hommasse', 'hermaphroditi']
  }, {
    description: '"{word}" is a slur against androgynous people',
    words: ['berdache']
  }, {
    description: '"{word}" is a slur against androgynous men',
    words: [['breck','girl']]
  }
];
